
# Load the required package
require(lme4)
# Run a simple mixed model
rely1way <- lmer(LnDepVar ~ 1 + (1 | AthleteID), data = rely2waylong)
# Produce the model output
summary(rely1way)
# Produce profile CI's at the 90% level
confint(rely2way, level=0.9)

# Include another random effect for a two way reliability model
rely2way <- lmer(LnDepVar ~ 1 + (1 | AthleteID) + (1 | GameID), 
                data = rely2waylong)
# Produce the summary
summary(rely2way)

# Run the above model with missing data points
rely2waymissplus <- lmer(LnDepVar ~ LoseTieWin + (1 | AthleteID) + 
                          (1 | GameID), data = rely2waylongmiss)
# Produce the summary
summary(rely2waymissplus)
# Produce CI's
confint(rely2waymissplus, level=0.9)

# Two way reliability model with missing values and a fixed effect
rely2waymissplus <- lmer(LnDepVar ~ LoseTieWin + (1 | AthleteID) + 
                           (1 | GameID), data = rely2waylongmiss)
# Produce the summary
summary(rely2waymissplus)
# Produce CI's
confint(rely2waymissplus, level=0.9)

# To produce all three means
rely2waymissplus <- lmer(LnDepVar ~ -1 + LoseTieWin + (1 | AthleteID) + 
                          (1 | GameID), data = rely2waylongmiss)
# Produce the summary
summary(rely2waymissplus)
# Extract the random effects
ranef(rely2waymissplus)
# Load the required pacakges
require(ggplot2)
require(lattice)
# Plot the random effects in rank order with CI's
dotplot(ranef(rely2waymissplus, condVar=TRUE))


# Import the data into R as a .csv or .txt file
# The code below can be used to import workbooks although DO NOT USE ON A MAC
# This code relies on a package (xlsx) that you will need to install into R first
# Change the file location dependent upon your own computer's file storage
require(xlsx)
SetsRepsLongFormat <- read.xlsx("c:/sets of reps long format.xlsx", 1)
# If importing as a .csv or .txt, change the data.frame to a "friendly" name for use in R
SetsRepsLongFormat <- sets.of.reps.long.format
# The following line of code is used to assess the structure of an imported data.frame
str(SetsRepsLongFormat)
# Athlete is an integer however, we want it as a factor. To do so, run the following line
SetsRepsLongFormat$Athlete <- as.factor(SetsRepsLongFormat$Athlete)
SetsRepsLongFormat$Set <- as.factor(SetsRepsLongFormat$Set)
# Assess how many levels or athletes there now are
levels(SetsRepsLongFormat$Athlete)

# Load the required package below, again you may need to install into R first
require(plyr)
# To obtain means, SD's, SE's and 95% CI's use the following code
SummaryData <- ddply(SetsRepsLongFormat,.(Set, Rep), summarise,
                     Mean = mean(Time),
                     SD = sd(Time),
                     LowerCI = quantile(Time, 0.05),
                     UpperCI = quantile(Time, 0.95))
# Make set a factor for plotting
SummaryData$Set <- as.factor(SummaryData$Set)
# The package below is an extensive tool for plotting in R with awesome graphs
# You may need to first install into R before running the line of code below
require(ggplot2)
# This code will plot the DV (Time) over each Rep within Set
ggplot(data = SummaryData, aes(x = Rep, y = Mean, colour = Set)) +
  geom_line() +
  geom_point() +
  ylab("Mean Time (s)\n") + 
  xlab("\nRepetition") + 
  scale_y_continuous(expand = c(0, 0), limits = c(7.9, 8.55)) +
  scale_x_continuous(expand = c(0, 0), limits = c(0.5, 6.5), breaks = c(1:6)) +
  theme_classic() +
  theme(legend.position = "bottom", 
        axis.line = element_line(color = "black", size = .7),
        axis.ticks = element_line(color = "black", size = .7),
        axis.text.y = element_text(colour="black", size=9),
        axis.text.x = element_text(colour="black", size=9),
        axis.title.y = element_text(face ="bold", colour="black", size=11),
        axis.title.x = element_text(face ="bold", colour="black", size=11))

# Include a new rep variable that goes from -0.5 to 0.5 rather than 1 to 6
SetsRepsLongFormat$RepRescaled <- ((SetsRepsLongFormat$Rep - 1)/5 - 0.5)

# The following package is required for linear mixed modelling in R
require(lme4)
# Construct the model
ClusteredTrial <- lmer(LnTime ~  -1 + Set + RepRescaled + Set:RepRescaled + xVarRep6 +
                 (0 + xVarRep6 | Athlete) + (1 | Set:Athlete) + 
                 (1 + RepRescaled | Athlete), 
                 data = SetsRepsLongFormat)
# Obtain the model summary
summary(ClusteredTrial)
